﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.ComponentModel;

namespace LocalizingValidation
{
    public class ValidationModel : INotifyPropertyChanged
    {
        private DateTime _ReleaseDate;
        public DateTime ReleaseDate
        {
            get
            {
                return this._ReleaseDate;
            }
            set
            {
                if (this._ReleaseDate != value)
                {
                    if (value.DayOfWeek == DayOfWeek.Sunday || value.DayOfWeek == DayOfWeek.Saturday)
                    {
                        throw new LocalizedException("Should be working day.", "NonWorkingDayError");
                    }
                    this._ReleaseDate = value;
                    this.OnNotifyPropertyChanged("ReleaseDate");
                }
            }
        }

        private int _BuildType;
        public int BuildType
        {
            get
            {
                return this._BuildType;
            }
            set
            {
                if (this._BuildType != value)
                {
                    if (value == 0)
                    {
                        throw new LocalizedException("Should be Release build.", "NonReleaseBuildError");
                    }
                    this._BuildType = value;
                    this.OnNotifyPropertyChanged("BuildType");
                }
            }
        }

        private double _Size;
        public double Size
        {
            get
            {
                return this._Size;
            }
            set
            {
                if (this._Size != value)
                {
                    if (value <= 3)
                    {
                        throw new LocalizedException("Should be greater than 3.", "SmallSizeError");
                    }
                    this._Size = value;
                    this.OnNotifyPropertyChanged("Size");
                }
            }
        }

        protected void OnNotifyPropertyChanged(string propertyName)
        {
            if (this.PropertyChanged != null)
            {
                this.PropertyChanged.Invoke(this, new PropertyChangedEventArgs(propertyName));
            }
        }
        public event PropertyChangedEventHandler PropertyChanged;
    }
}
